==> labplot-2.1.0.tar.xz: labplot-2.1.0/src/kdefrontend/HistoryDialog.h <==

/***************************************************************************
    File                 : HistoryDialog.h
    Project              : LabPlot
    Description          : history dialog
    --------------------------------------------------------------------
    Copyright            : (C) 2012 by Alexander Semke
    Email (use @ for *)  : alexander.semke*web.de

 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *  This program is free software; you can redistribute it and/or modify   *
 *  it under the terms of the GNU General Public License as published by   *
 *  the Free Software Foundation; either version 2 of the License, or      *
 *  (at your option) any later version.                                    *
 *                                                                         *
 *  This program is distributed in the hope that it will be useful,        *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
 *  GNU General Public License for more details.                           *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the Free Software           *
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
 *   Boston, MA  02110-1301  USA                                           *
 *                                                                         *
 ***************************************************************************/

#ifndef HISTORYDIALOG_H
#define HISTORYDIALOG_H

#include <KDialog>
class Project;
class QUndoStack;

class HistoryDialog: public KDialog {
  Q_OBJECT

  public:
	HistoryDialog(QWidget* parent, QUndoStack* project, QString& emptyLabel);

  private:
	QUndoStack* m_undoStack;
	
  private slots:
	  void clearUndoStack();
};

#endif

==> labplot-2.4.0.tar.xz: labplot-2.4.0/src/kdefrontend/HistoryDialog.h <==

/***************************************************************************
    File                 : HistoryDialog.h
    Project              : LabPlot
    Description          : history dialog
    --------------------------------------------------------------------
    Copyright            : (C) 2012-2016 by Alexander Semke (alexander.semke@web.de)

 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *  This program is free software; you can redistribute it and/or modify   *
 *  it under the terms of the GNU General Public License as published by   *
 *  the Free Software Foundation; either version 2 of the License, or      *
 *  (at your option) any later version.                                    *
 *                                                                         *
 *  This program is distributed in the hope that it will be useful,        *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
 *  GNU General Public License for more details.                           *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the Free Software           *
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
 *   Boston, MA  02110-1301  USA                                           *
 *                                                                         *
 ***************************************************************************/

#ifndef HISTORYDIALOG_H
#define HISTORYDIALOG_H

#include <KDialog>
class QUndoStack;

class HistoryDialog: public KDialog {
	Q_OBJECT

public:
	HistoryDialog(QWidget*, QUndoStack*, const QString&);
	~HistoryDialog();

private:
	QUndoStack* m_undoStack;

private slots:
	void clearUndoStack();
};

#endif
